\name{emplikH1.test}
\alias{emplikH1.test}
\title{Empirical likelihood for hazard with right censored data}
\usage{
emplikH1.test(x, d, theta, fun, tola=.Machine$double.eps^.25)
}
\description{Use empirical likelihood ratio and Wilks theorem to test 
the null hypothesis that 
\deqn{\int f(t) dH(t) = \theta }
with right censored data. Where \eqn{H(t)} is the cumulative hazard 
function; \eqn{f(t)} can be any given left continuous function and
\eqn{\theta} a given constant. In fact, \eqn{f(t)} can even be data
dependent, just have to be `predictable'.
}
\arguments{
    \item{x}{a vector containing the observed survival times.}
    \item{d}{a vector containing the censoring indicators, 1-uncensor; 0-censor.}
    \item{theta}{a real number used in the Ho to set the hazard to this value.}
    \item{fun}{a left continuous (weight) function used to calculate 
         the weighted hazard in Ho. \code{fun} must be able to take a vector input.}
    \item{tola}{an optional positive real number specifying the tolerance of
       iteration error in solve the non-linear equation needed in constrained 
        maximization.}
}
\details{
There are two version of the likelihood. the Poisson likelihood
and the binomial likelihood. When the true cumulative hazard \eqn{H(t)}
is continuous, the Poisson seems to work better.
}
\value{
    A list with the following components:
    \item{times}{the location of the hazard jumps.}
    \item{wts}{the jump size of hazard function at those locations.}
    \item{lambda}{the Lagrange multiplier.}
    \item{"-2LLR"}{the -2Log Likelihood ratio.}
    \item{Pval}{P-value}
    \item{niters}{number of iterations used}
}
\references{
    Pan and Zhou (1999),
    ``Empirical likelihood in terms of hazard for censored data''. 
    \emph{Journal of Multivariate Analysis} \bold{83},
}
\examples{
fun <- function(x) { as.numeric(x <= 6.5) }
emplikH1.test( c(1,2,3,4,5), c(1,1,0,1,1), 2, fun) 

fun2 <- function(x) {exp(-x)}  
emplikH1.test( c(1,2,3,4,5), c(1,1,0,1,1), theta=0.2, fun2) 
}
\keyword{nonparametric}
\keyword{survival}
\keyword{htest}
