\name{emplikH2.test}
\alias{emplikH2.test}
\title{Empirical likelihood for weighted hazard with right censored data}
\usage{
emplikH2.test(x, d, K, fun, tola=.Machine$double.eps^.25,...)
}
\description{Use empirical likelihood ratio and Wilks theorem to test 
the null hypothesis that 
\deqn{\int f(t, ... ) dH(t) = K }
with right censored data, where \eqn{ H(t) } is the (unknown)
cumulative hazard function;
\eqn{ f(t, ... )} can be any given left continuous function in \eqn{t};
(of course the integration must be finite). 
}
\arguments{
    \item{x}{a vector containing the observed survival times.}
    \item{d}{a vector of the censoring indicators, 1-uncensor; 0-censor.}

    \item{K}{a real number used in the constraint, i.e. to set the
               weighted integral of hazard to this value.}
    \item{fun}{a left continuous (in \code{t}) weight function 
              used to calculate 
         the weighted hazard in \eqn{H_0}. \code{fun(t, ... )} must be 
         able to take a vector input \code{t}.}
    \item{tola}{an optional positive real number specifying the tolerance of
       iteration error in solve the non-linear equation needed in constrained
        maximization.}
    \item{...}{additional parameter(s) passing along to \code{fun}. This
           allows an implicit function of \code{fun}.  }
}
\value{
    A list with the following components:
    \item{times}{the location of the hazard jumps.}
    \item{wts}{the jump size of hazard function at those locations.}
    \item{lambda}{the Lagrange multiplier.}
    \item{``-2LLR"}{the -2Log Likelihood ratio.}
    \item{Pval}{P-value}
    \item{niters}{number of iterations used}
}
\author{ Mai Zhou } 
\references{
    Pan and Zhou (1999),
    ``Empirical likelihood in terms of hazard for censored data''. 
    \emph{Journal of Multivariate Analysis} \bold{83}
}
\examples{
z1<-c(1,2,3,4,5)
d1<-c(1,1,0,1,1)
fun4 <- function(x, theta) { as.numeric(x <= theta) }
emplikH2.test(z1,d1, K=0.5, fun4, theta=3.5)
#psum <- function(...) { 
#             args <- do.call("cbind", list(...))
#             nargs <- ncol(args)
#             as.vector(args %*% rep(1, nargs))
#}
#fun3 <- function(t, z) { psum( t( outer(z, t, FUN=">=") ) ) } 
#
#emplikH2.test(z1, d1, K=sum(0.25* z1), fun3, z=z1) 
}
\keyword{nonparametric}
\keyword{survival}
\keyword{htest}
